const express = require('express');
const app = express();
const swaggerJsDoc = require('swagger-jsdoc');
const swaggerUI = require('swagger-ui-express');

const swaggerOptions = {
  swaggerDefinition: {
    info: {
      title: "Books API",
      version: '1.0.0',
    },
  },
  apis: ["app.js"],
};

const swaggerDocs = swaggerJsDoc(swaggerOptions);
app.use('/api-docs', swaggerUI.serve, swaggerUI.setup(swaggerDocs));


/**
 * @swagger
 * /books:
 *   get:
 *     description: Get all books
 *     responses:
 *       200:
 *         description: Success
 *       404:
 *         description: Not found
 * 
 */
app.get('/books', (req, res) => {
  res.send([
    {
      id: 1,
      title: "Harry Potter",
    },
    {
      id: 2,
      title: "Червената шапчица",
    }
  ])
});

/**
 * @swagger
 * /books:
 *   post:
 *     description: Add new book
 *     parameters:
 *      - name: title
 *        description: title of the book
 *        in: formData
 *        required: true
 *        type: string
 *     responses:
 *       201:
 *         description: Created
 */
app.post('/books', (req, res) => {
  res.status(201).send();
});

app.listen(8080, () => console.log("listening on 8080"));